==> engine-2.2.6.tgz: package/src/request/uploader/mime.ts <==
export default {
	'image/jpeg': ['jpeg', 'jpg', 'jpe'],
	'image/png': ['png'],
	'image/gif': ['gif'],
	'image/vnd.wap.wbmp': ['wbmp'],
	'image/tiff': ['tiff', 'tiff'],
	'image/vnd.adobe.photoshop': ['psd'],
	'image/svg+xml': ['svg', 'svgz'],
	'text/jsx': ['jsx'],
	'text/less': ['less'],
	'text/css': ['css'],
	'text/x-sass': ['sass'],
	'text/x-scss': ['scss'],
	'text/csv': ['cvs'],
	'text/xml': ['xml'],
	'text/x-vcard': ['vcf'],
	'text/x-vcalendar': ['vcs'],
	'text/markdown': ['md'],
	'text/plain': ['txt'],
	'text/richtext': ['rtx'],
	'text/rtf': ['rtf'],
	'text/html': ['html', 'htm', 'shtml'],
	'text/jade': ['jade'],
	'text/javascript': ['js'],
	'text/yaml': ['yaml', 'yml'],
	'audio/mp3': ['mp3'],
	'audio/mp4': ['mp4', 'mp4a'],
	'video/mp4': ['mp4'],
	'audio/mpeg': ['mpeg', 'mp2', 'mp3'],
	'audio/ogg': ['oga'],
	'audio/wav': ['wav'],
	'audio/wave': ['wav'],
	'audio/webm': ['weba'],
	'video/x-msvideo': ['avi'],
	'video/quicktime': ['mov', 'qt'],
	'video/ogg': ['ogv'],
	'video/x-sgi-movie': ['movie'],
	'application/rss+xml': ['rss'],
	'application/json': ['json'],
	'application/zip': ['zip'],
	'application/gzip': ['gzip'],
	'application/pdf': ['pdf'],
	'application/postscript': ['ai', 'eps', 'ps'],
	'application/msword': ['doc', 'dot'],
	'application/vnd.openxmlformats-officedocument.wordprocessingml.document': [
		'docx',
	],
	'application/vnd.openxmlformats-officedocument.wordprocessingml.template': [
		'dotx',
	],
	'application/vnd.ms-excel': ['xls', 'xlm', 'xla', 'xlc', 'xlt', 'xlw'],
	'application/vnd.ms-excel.sheet.macroenabled.12': ['xlsm'],
	'application/vnd.openxmlformats-officedocument.spreadsheetml.sheet': [
		'xlsx',
	],
	'application/vnd.openxmlformats-officedocument.spreadsheetml.template': [
		'xltx',
	],
	'application/vnd.ms-powerpoint': ['ppt', 'pps', 'pot'],
	'application/vnd.openxmlformats-officedocument.presentationml.presentation': [
		'pptx',
	],
	'application/vnd.openxmlformats-officedocument.presentationml.slide': [
		'sldx',
	],
	'application/vnd.openxmlformats-officedocument.presentationml.slideshow': [
		'ppsx',
	],
	'application/vnd.openxmlformats-officedocument.presentationml.template': [
		'potx',
	],
	'application/vnd.ms-fontobject': ['eot'],
	'application/vnd.android.package-archive': ['apk'],
	'application/x-apple-diskimage': ['dmg'],
	'application/x-iwork-keynote-sffkey': ['key'],
	'application/x-iwork-pages-sffpages': ['pages'],
	'application/x-iwork-keynote-sffnumbers': ['numbers'],
	'application/x-iwork-numbers-sffnumbers': ['numbers'],
};

==> engine-2.6.18.tgz: package/src/request/uploader/mime.ts <==
export default {
	'image/jpeg': ['jpeg', 'jpg', 'jpe'],
	'image/png': ['png'],
	'image/gif': ['gif'],
	'image/vnd.wap.wbmp': ['wbmp'],
	'image/tiff': ['tiff', 'tiff'],
	'image/vnd.adobe.photoshop': ['psd'],
	'image/svg+xml': ['svg', 'svgz'],
	'text/jsx': ['jsx'],
	'text/less': ['less'],
	'text/css': ['css'],
	'text/x-sass': ['sass'],
	'text/x-scss': ['scss'],
	'text/csv': ['cvs'],
	'text/xml': ['xml'],
	'text/x-vcard': ['vcf'],
	'text/x-vcalendar': ['vcs'],
	'text/markdown': ['md'],
	'text/plain': ['txt'],
	'text/richtext': ['rtx'],
	'text/rtf': ['rtf'],
	'text/html': ['html', 'htm', 'shtml'],
	'text/jade': ['jade'],
	'text/javascript': ['js'],
	'text/yaml': ['yaml', 'yml'],
	'audio/mp3': ['mp3'],
	'audio/mp4': ['mp4', 'mp4a'],
	'video/mp4': ['mp4'],
	'audio/mpeg': ['mpeg', 'mp2', 'mp3'],
	'audio/ogg': ['oga'],
	'audio/wav': ['wav'],
	'audio/wave': ['wav'],
	'audio/webm': ['weba'],
	'video/x-msvideo': ['avi'],
	'video/quicktime': ['mov', 'qt'],
	'video/ogg': ['ogv'],
	'video/x-sgi-movie': ['movie'],
	'application/rss+xml': ['rss'],
	'application/json': ['json'],
	'application/zip': ['zip'],
	'application/gzip': ['gzip'],
	'application/pdf': ['pdf'],
	'application/postscript': ['ai', 'eps', 'ps'],
	'application/msword': ['doc', 'dot'],
	'application/vnd.openxmlformats-officedocument.wordprocessingml.document': [
		'docx',
	],
	'application/vnd.openxmlformats-officedocument.wordprocessingml.template': [
		'dotx',
	],
	'application/vnd.ms-excel': ['xls', 'xlm', 'xla', 'xlc', 'xlt', 'xlw'],
	'application/vnd.ms-excel.sheet.macroenabled.12': ['xlsm'],
	'application/vnd.openxmlformats-officedocument.spreadsheetml.sheet': [
		'xlsx',
	],
	'application/vnd.openxmlformats-officedocument.spreadsheetml.template': [
		'xltx',
	],
	'application/vnd.ms-powerpoint': ['ppt', 'pps', 'pot'],
	'application/vnd.openxmlformats-officedocument.presentationml.presentation':
		['pptx'],
	'application/vnd.openxmlformats-officedocument.presentationml.slide': [
		'sldx',
	],
	'application/vnd.openxmlformats-officedocument.presentationml.slideshow': [
		'ppsx',
	],
	'application/vnd.openxmlformats-officedocument.presentationml.template': [
		'potx',
	],
	'application/vnd.ms-fontobject': ['eot'],
	'application/vnd.android.package-archive': ['apk'],
	'application/x-apple-diskimage': ['dmg'],
	'application/x-iwork-keynote-sffkey': ['key'],
	'application/x-iwork-pages-sffpages': ['pages'],
	'application/x-iwork-keynote-sffnumbers': ['numbers'],
	'application/x-iwork-numbers-sffnumbers': ['numbers'],
};
